@@ -2,10 +2,8 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
-from typing import Iterable
-
 from . import request
-from .base import BaseClient, CallbackFnType, InputType
+from .base import BaseClient, CallbackFnType, InputType, InputDeleteType
 from .helper import callback_exec
 from .request import GeneratorSourceType
 from .websocket import WebSocketClientMixin
@@ -149,7 +147,7 @@ class Client(BaseClient):
     )
     def delete(
         self,
-        inputs: Iterable[str],
+        inputs: InputDeleteType,
         on_done: CallbackFnType = None,
         on_error: CallbackFnType = None,
         on_always: CallbackFnType = None,
@@ -157,7 +155,7 @@ class Client(BaseClient):
     ) -> None:
         """Issue 'update' request to the Flow.
 
-        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document
+        :param inputs: input data which can be an Iterable, a function which returns an Iterable, or a single Document id.
         :param on_done: the function to be called when the :class:`Request` object is resolved.
         :param on_error: the function to be called when the :class:`Request` object is rejected.
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
