@@ -16,22 +16,19 @@ COL_STR_TYPE = 'U64'  #: the ID column data type for score matrix
 
 
 class BaseAggregateMatchesRankerDriver(BaseRankDriver):
-    """Drivers inherited from this Driver focus on aggregating scores from `chunks` to its `parents`."""
+    """Drivers inherited from this Driver focus on aggregating scores from `chunks` to its `parents`.
 
-    def __init__(self, keep_source_matches_as_chunks: bool = False, *args, **kwargs):
-        """
-
-        :param keep_source_matches_as_chunks: A flag to indicate if the driver must return the old matches of the query or its chunks
+    :param keep_source_matches_as_chunks: A flag to indicate if the driver must return the old matches of the query or its chunks
             (at a greater granularity level (k + 1)) as the chunks of the new computed `matches` (at granularity level k)
             Set it to `True` when keeping track of the chunks that lead to a retrieved result.
-        :param *args: *args for super
-        :param **kwargs: **kwargs for super
+    :param args: additional positional arguments which are just used for the parent initialization
+    :param kwargs: additional key value arguments which are just used for the parent initialization
 
-        .. note::
-            When set `keep_source_matches_as_chunks=True`, the chunks of the match contains **ONLY** the chunks leading
-            to the match rather than **ALL** the chunks of the match.
+    .. note::
+        When set `keep_source_matches_as_chunks=True`, the chunks of the match contains **ONLY** the chunks leading
+        to the match rather than **ALL** the chunks of the match."""
 
-        """
+    def __init__(self, keep_source_matches_as_chunks: bool = False, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.keep_source_matches_as_chunks = keep_source_matches_as_chunks
 
@@ -72,30 +69,37 @@ class BaseAggregateMatchesRankerDriver(BaseRankDriver):
 
     @staticmethod
     def _group_by(match_idx, col_name):
-        # sort by ``col
+        """
+        Create an list of numpy arrays with the same ``col_name`` in each position of the list
+
+        :param match_idx: Numpy array of Tuples with document id and score
+        :param col_name:  Column name in the structured numpy array of Tuples
+
+        :return: List of numpy arrays with the same ``doc_id`` in each position of the list
+        :rtype: np.ndarray.
+        """
         _sorted_m = np.sort(match_idx, order=col_name)
-        _, _doc_counts = np.unique(_sorted_m[col_name], return_counts=True)
-        # group by ``col``
-        return np.split(_sorted_m, np.cumsum(_doc_counts))[:-1]
+        n_elements = len(_sorted_m[col_name])
+        list_numpy_arrays = []
+        prev_val = _sorted_m[col_name][0]
+        prev_index = 0
+        for i, current_val in enumerate(_sorted_m[col_name]):
+            if current_val != prev_val:
+                list_numpy_arrays.append(_sorted_m[prev_index:i])
+                prev_index = i
+                prev_val = current_val
+        list_numpy_arrays.append(_sorted_m[prev_index:])
+        return list_numpy_arrays
 
     @staticmethod
     def _sort_doc_by_score(r):
         """
-        Sort a list of (``doc_id``, ``score``) tuples by the ``score``.
+        Sort a numpy array  of dtype (``doc_id``, ``score``) by the ``score``.
 
-        :param r: List of Tuples with document id and score
-        :type r: List[Tuple[np.str_, np.float64]]
-        :return: A `np.ndarray` in the shape of [N x 2], where `N` in the length of the input list.
-        :rtype: np.ndarray
+        :param r: Numpy array of Tuples with document id and score
+        :type r: np.ndarray[Tuple[np.str_, np.float64]]
         """
-        r = np.array(
-            r,
-            dtype=[
-                (Chunk2DocRanker.COL_PARENT_ID, COL_STR_TYPE),
-                (Chunk2DocRanker.COL_SCORE, np.float64),
-            ],
-        )
-        return np.sort(r, order=Chunk2DocRanker.COL_SCORE)[::-1]
+        r[::-1].sort(order=Chunk2DocRanker.COL_SCORE)
 
     def _score(
         self, match_idx: 'np.ndarray', query_chunk_meta: Dict, match_chunk_meta: Dict
@@ -120,12 +124,23 @@ class BaseAggregateMatchesRankerDriver(BaseRankDriver):
         :rtype: np.ndarray.
         """
         _groups = self._group_by(match_idx, Chunk2DocRanker.COL_PARENT_ID)
-        r = []
-        for _g in _groups:
-            match_id = _g[0][Chunk2DocRanker.COL_PARENT_ID]
-            score = self.exec_fn(_g, query_chunk_meta, match_chunk_meta)
-            r.append((match_id, score))
-        return self._sort_doc_by_score(r)
+        n_groups = len(_groups)
+        res = np.empty(
+            (n_groups,),
+            dtype=[
+                (Chunk2DocRanker.COL_PARENT_ID, COL_STR_TYPE),
+                (Chunk2DocRanker.COL_SCORE, np.float64),
+            ],
+        )
+
+        for i, _g in enumerate(_groups):
+            res[i] = (
+                _g[Chunk2DocRanker.COL_PARENT_ID][0],
+                self.exec_fn(_g, query_chunk_meta, match_chunk_meta),
+            )
+
+        self._sort_doc_by_score(res)
+        return res
 
 
 class Chunk2DocRankDriver(BaseAggregateMatchesRankerDriver):
@@ -157,8 +172,8 @@ class Chunk2DocRankDriver(BaseAggregateMatchesRankerDriver):
     def _apply_all(self, docs: 'DocumentSet', *args, **kwargs) -> None:
         """
         :param docs: the doc which gets bubbled up matches
-        :param *args: not used (kept to maintain interface)
-        :param **kwargs: not used (kept to maintain interface)
+        :param args: not used (kept to maintain interface)
+        :param kwargs: not used (kept to maintain interface)
         """
         for doc in docs:
             chunks = doc.chunks
@@ -238,8 +253,8 @@ class AggregateMatches2DocRankDriver(BaseAggregateMatchesRankerDriver):
         """
 
         :param docs: the document at granularity ``k``
-        :param *args: not used (kept to maintain interface)
-        :param **kwargs: not used (kept to maintain interface)
+        :param args: not used (kept to maintain interface)
+        :param kwargs: not used (kept to maintain interface)
 
         .. note::
             - This driver will substitute the ``matches`` of `docs` to the corresponding ``parent documents`` of its current ``matches`` according
