@@ -17,7 +17,7 @@ if False:
 
 
 class BaseSearchDriver(BaseExecutableDriver):
-    """Drivers inherited from this Driver will bind :meth:`craft` by default """
+    """Drivers inherited from this Driver will bind :meth:`query` by default """
 
     def __init__(
         self,
@@ -49,6 +49,12 @@ class KVSearchDriver(ContextAwareRecursiveMixin, BaseSearchDriver):
             - D is the number of queries
             - C is the number of chunks per document
             - K is the top-k
+
+        :param is_update: when set to true the retrieved docs are merged into current message;
+            otherwise, the retrieved Document overrides the existing Document
+        :param traversal_paths: traversal paths for the driver
+        :param args: additional positional arguments which are just used for the parent initialization
+        :param kwargs: additional key value arguments which are just used for the parent initialization
     """
 
     def __init__(
@@ -58,14 +64,6 @@ class KVSearchDriver(ContextAwareRecursiveMixin, BaseSearchDriver):
         *args,
         **kwargs,
     ):
-        """Construct the driver.
-
-        :param is_update: when set to true the retrieved docs are merged into current message;
-            otherwise, the retrieved Document overrides the existing Document
-        :param traversal_paths: traversal paths for the driver
-        :param *args: *args for super
-        :param **kwargs: **kwargs for super
-        """
         super().__init__(traversal_paths=traversal_paths, *args, **kwargs)
         self._is_update = is_update
 
@@ -110,17 +108,15 @@ class VectorFillDriver(FlatRecursiveMixin, QuerySetReader, BaseSearchDriver):
 
 
 class VectorSearchDriver(FlatRecursiveMixin, QuerySetReader, BaseSearchDriver):
-    """Extract embeddings from the request for the executor to query."""
+    """Extract embeddings from the request for the executor to query.
+
+    :param top_k: top-k document ids to retrieve
+    :param fill_embedding: fill in the embedding of the corresponding doc,
+            this requires the executor to implement :meth:`query_by_key`
+    :param args: additional positional arguments which are just used for the parent initialization
+    :param kwargs: additional key value arguments which are just used for the parent initialization"""
 
     def __init__(self, top_k: int = 50, fill_embedding: bool = False, *args, **kwargs):
-        """Construct the driver.
-
-        :param top_k: top-k document ids to retrieve
-        :param fill_embedding: fill in the embedding of the corresponding doc,
-                this requires the executor to implement :meth:`query_by_key`
-        :param *args: *args for super
-        :param **kwargs: **kwargs for super
-        """
         super().__init__(*args, **kwargs)
         self._top_k = top_k
         self._fill_embedding = fill_embedding
