@@ -72,8 +72,8 @@ class BaseNumpyIndexer(BaseVectorIndexer):
                 f'num_dim extracted from `ref_indexer` to {ref_indexer.num_dim} \n'
                 f'_size extracted from `ref_indexer` to {ref_indexer._size} \n'
                 f'dtype extracted from `ref_indexer` to {ref_indexer.dtype} \n'
-                f'compress_level overriden from `ref_indexer` to {ref_indexer.compress_level} \n'
-                f'index_filename overriden from `ref_indexer` to {ref_indexer.index_filename}'
+                f'compress_level overridden from `ref_indexer` to {ref_indexer.compress_level} \n'
+                f'index_filename overridden from `ref_indexer` to {ref_indexer.index_filename}'
             )
             self.ref_indexer_workspace_name = ref_indexer.workspace_name
             self.delete_on_dump = getattr(ref_indexer, 'delete_on_dump', delete_on_dump)
@@ -479,8 +479,8 @@ class NumpyIndexer(BaseNumpyIndexer):
             Distance (the smaller the better) is returned, not the score.
 
         :param vectors: the vectors with which to search
-        :param *args: not used
-        :param **kwargs: not used
+        :param args: not used
+        :param kwargs: not used
         :param top_k: nr of results to return
         :return: tuple of indices within matrix and distances
         """
@@ -494,8 +494,6 @@ class NumpyIndexer(BaseNumpyIndexer):
         elif self.metric == 'cosine':
             _query_vectors = _ext_A(_norm(vectors))
             dist = self._cosine(_query_vectors, self.query_handler)
-        else:
-            raise NotImplementedError(f'{self.metric} is not implemented')
 
         idx, dist = self._get_sorted_top_k(dist, top_k)
         indices = self._int2ext_id[self.valid_indices][idx]
