@@ -4,19 +4,19 @@ from jina.executors.evaluators.embedding import BaseEmbeddingEvaluator, expand_v
 
 
 class InfiniteNormEvaluator(BaseEmbeddingEvaluator):
-    """A :class:`InfiniteNormEvaluator` evaluates the distance between actual and desired embeddings computing
-    the Infinite Norm between them
     """
-
-    @property
-    def metric(self):
-        return 'InfiniteNormEvaluator'
+    :class:`InfiniteNormEvaluator` evaluates distance between actual and desired
+    embeddings computing the Infinite Norm between them.
+    """
 
     def evaluate(self, actual: 'np.array', desired: 'np.array', *args, **kwargs) -> float:
         """"
-        :param actual: the embedding of the document (resulting from an Encoder)
+        :param actual: the embedding of the document
+            (resulting from an Encoder)
         :param desired: the expected embedding of the document
-        :return the evaluation metric value for the request document
+        :return: the evaluation metric value for the request document
+        :param args:  Additional positional arguments
+        :param kwargs: Additional keyword arguments
         """
         actual = expand_vector(actual)
         desired = expand_vector(desired)
