@@ -7,7 +7,7 @@ import urllib.parse
 import urllib.request
 import warnings
 from hashlib import blake2b
-from typing import Union, Dict, Optional, TypeVar, Any, Tuple
+from typing import Union, Dict, Optional, TypeVar, Any, Tuple, List
 
 import numpy as np
 from google.protobuf import json_format
@@ -246,12 +246,18 @@ class Document(ProtoTypeMixin, Traversable):
 
     @modality.setter
     def modality(self, value: str):
-        """Set the modality of the document."""
+        """Set the modality of the document.
+
+        :param value: The modality of the document
+        """
         self._pb_body.modality = value
 
     @property
     def content_hash(self):
-        """Get the content hash of the document."""
+        """Get the content hash of the document.
+
+        :return: the content_hash from the proto
+        """
         return self._pb_body.content_hash
 
     @staticmethod
@@ -276,7 +282,7 @@ class Document(ProtoTypeMixin, Traversable):
 
         .. note::
             *. if neither ``exclude_fields`` nor ``include_fields`` is given,
-                then destination is overrided by the source completely.
+                then destination is overridden by the source completely.
             *. ``destination`` will be modified in place, ``source`` will be unchanged
         """
 
@@ -413,6 +419,8 @@ class Document(ProtoTypeMixin, Traversable):
     def id(self) -> str:
         """The document id in hex string, for non-binary environment such as HTTP, CLI, HTML and also human-readable.
         it will be used as the major view.
+
+        :return: the id from the proto
         """
         return self._pb_body.id
 
@@ -420,6 +428,8 @@ class Document(ProtoTypeMixin, Traversable):
     def parent_id(self) -> str:
         """The document's parent id in hex string, for non-binary environment such as HTTP, CLI, HTML and also human-readable.
         it will be used as the major view.
+
+        :return: the parent id from the proto
         """
         return self._pb_body.parent_id
 
@@ -428,7 +438,6 @@ class Document(ProtoTypeMixin, Traversable):
         """Set document id to a string value.
 
         :param value: id as bytes, int or str
-        :return:
         """
         self._pb_body.id = str(value)
 
@@ -437,7 +446,6 @@ class Document(ProtoTypeMixin, Traversable):
         """Set document's parent id to a string value.
 
         :param value: id as bytes, int or str
-        :return:
         """
         self._pb_body.parent_id = str(value)
 
@@ -447,22 +455,33 @@ class Document(ProtoTypeMixin, Traversable):
 
         .. note::
             Use :attr:`content` to return the content of a Document
+
+        :return: the blob content from the proto
         """
         return NdArray(self._pb_body.blob).value
 
     @blob.setter
     def blob(self, value: Union['np.ndarray', 'jina_pb2.NdArrayProto', 'NdArray']):
-        """Set the `blob` to :param:`value`."""
+        """Set the `blob` to :param:`value`.
+
+        :param value: the array value to set the blob
+        """
         self._update_ndarray('blob', value)
 
     @property
     def embedding(self) -> 'np.ndarray':
-        """Return ``embedding`` of the content of a Document."""
+        """Return ``embedding`` of the content of a Document.
+
+        :return: the embedding from the proto
+        """
         return NdArray(self._pb_body.embedding).value
 
     @embedding.setter
     def embedding(self, value: Union['np.ndarray', 'jina_pb2.NdArrayProto', 'NdArray']):
-        """Set the ``embedding`` of the content of a Document."""
+        """Set the ``embedding`` of the content of a Document.
+
+        :param value: the array value to set the embedding
+        """
         self._update_ndarray('embedding', value)
 
     def _update_ndarray(self, k, v):
@@ -478,20 +497,34 @@ class Document(ProtoTypeMixin, Traversable):
 
     @property
     def matches(self) -> 'MatchSet':
-        """Get all matches of the current document."""
+        """Get all matches of the current document.
+
+        :return: the set of matches attached to this document
+        """
         return MatchSet(self._pb_body.matches, reference_doc=self)
 
     @property
     def chunks(self) -> 'ChunkSet':
-        """Get all chunks of the current document."""
+        """Get all chunks of the current document.
+
+        :return: the set of chunks of this document
+        """
         return ChunkSet(self._pb_body.chunks, reference_doc=self)
 
+    def __getattr__(self, item):
+        if hasattr(self._pb_body, item):
+            value = getattr(self._pb_body, item)
+        else:
+            value = dunder_get(self._pb_body, item)
+        return value
+
     def set_attrs(self, **kwargs):
         """Bulk update Document fields with key-value specified in kwargs
 
         .. seealso::
             :meth:`get_attrs` for bulk get attributes
 
+        :param kwargs: the keyword arguments to set the values, where the keys are the fields to set
         """
         for k, v in kwargs.items():
             if isinstance(v, (list, tuple)):
@@ -543,16 +576,15 @@ class Document(ProtoTypeMixin, Traversable):
                 assert res['tags__hello'] == 'world' # true
                 assert res['tags__good'] == 'bye' # true
                 assert res['tags__id'] == 'external_id' # true
+
+        :param args: the variable length values to extract from the document
+        :return: a dictionary mapping the fields in `:param:args` to the actual attributes of this document
         """
 
         ret = {}
         for k in args:
-
             try:
-                if hasattr(self, k):
-                    value = getattr(self, k)
-                else:
-                    value = dunder_get(self._pb_body, k)
+                value = getattr(self, k)
 
                 if value is None:
                     raise ValueError
@@ -565,18 +597,63 @@ class Document(ProtoTypeMixin, Traversable):
                 ret[k] = None
         return ret
 
+    def get_attrs_values(self, *args) -> List[Any]:
+        """Bulk fetch Document fields and return a list of the values of these fields
+
+        .. note::
+            Arguments will be extracted using `dunder_get`
+            .. highlight:: python
+            .. code-block:: python
+
+                d = Document({'id': '123', 'hello': 'world', 'tags': {'id': 'external_id', 'good': 'bye'}})
+
+                assert d.id == '123'  # true
+                assert d.tags['hello'] == 'world' # true
+                assert d.tags['good'] == 'bye' # true
+                assert d.tags['id'] == 'external_id' # true
+
+                res = d.get_attrs_values(*['id', 'tags__hello', 'tags__good', 'tags__id'])
+
+                assert res == ['123', 'world', 'bye', 'external_id']
+
+        :param args: the variable length values to extract from the document
+        :return: a list with the attributes of this document ordered as the args
+        """
+
+        ret = []
+        for k in args:
+            try:
+                value = getattr(self, k)
+
+                if value is None:
+                    raise ValueError
+
+                ret.append(value)
+            except (AttributeError, ValueError):
+                default_logger.warning(
+                    f'Could not get attribute `{typename(self)}.{k}`, returning `None`'
+                )
+                ret.append(None)
+
+        return ret
+
     @property
     def buffer(self) -> bytes:
         """Return ``buffer``, one of the content form of a Document.
 
         .. note::
             Use :attr:`content` to return the content of a Document
+
+        :return: the buffer bytes from this document
         """
         return self._pb_body.buffer
 
     @buffer.setter
     def buffer(self, value: bytes):
-        """Set the ``buffer`` to :param:`value`."""
+        """Set the ``buffer`` to :param:`value`.
+
+        :param value: the bytes value to set the buffer
+        """
         self._pb_body.buffer = value
         if value and not self._pb_body.mime_type:
             with ImportExtensions(
@@ -596,18 +673,26 @@ class Document(ProtoTypeMixin, Traversable):
 
         .. note::
             Use :attr:`content` to return the content of a Document
+
+        :return: the text from this document content
         """
         return self._pb_body.text
 
     @text.setter
     def text(self, value: str):
-        """Set the `text` to :param:`value`"""
+        """Set the `text` to :param:`value`
+
+        :param value: the text value to set as content
+        """
         self._pb_body.text = value
         self.mime_type = 'text/plain'
 
     @property
     def uri(self) -> str:
-        """Return the URI of the document."""
+        """Return the URI of the document.
+
+        :return: the uri from this document proto
+        """
         return self._pb_body.uri
 
     @uri.setter
@@ -618,7 +703,6 @@ class Document(ProtoTypeMixin, Traversable):
             :attr:`mime_type` will be updated accordingly
 
         :param value: acceptable URI/URL, raise ``ValueError`` when it is not a valid URI
-        :return:
         """
         scheme = urllib.parse.urlparse(value).scheme
         if (
@@ -634,7 +718,10 @@ class Document(ProtoTypeMixin, Traversable):
 
     @property
     def mime_type(self) -> str:
-        """Get MIME type of the document"""
+        """Get MIME type of the document
+
+        :return: the mime_type from this document proto
+        """
         return self._pb_body.mime_type
 
     @mime_type.setter
@@ -662,7 +749,10 @@ class Document(ProtoTypeMixin, Traversable):
 
     @property
     def content_type(self) -> str:
-        """Return the content type of the document, possible values: text, blob, buffer"""
+        """Return the content type of the document, possible values: text, blob, buffer
+
+        :return: the type of content present in this document proto
+        """
         return self._pb_body.WhichOneof('content')
 
     @property
@@ -672,6 +762,8 @@ class Document(ProtoTypeMixin, Traversable):
 
         .. seealso::
             :attr:`blob`, :attr:`buffer`, :attr:`text`
+
+        :return: the value of the content depending on `:meth:`content_type`
         """
         attr = self.content_type
         if attr:
@@ -683,6 +775,8 @@ class Document(ProtoTypeMixin, Traversable):
 
         .. seealso::
             :attr:`blob`, :attr:`buffer`, :attr:`text`
+
+        :param value: the value from which to set the content of the Document
         """
         if isinstance(value, bytes):
             self.buffer = value
@@ -703,32 +797,50 @@ class Document(ProtoTypeMixin, Traversable):
 
     @property
     def granularity(self):
-        """Return the granularity of the document."""
+        """Return the granularity of the document.
+
+        :return: the granularity from this document proto
+        """
         return self._pb_body.granularity
 
     @granularity.setter
-    def granularity(self, granularity_value: int):
-        """Set the granularity of the document."""
-        self._pb_body.granularity = granularity_value
+    def granularity(self, value: int):
+        """Set the granularity of the document.
+
+        :param value: the value of the granularity to be set
+        """
+        self._pb_body.granularity = value
 
     @property
     def adjacency(self):
-        """Return the adjacency of the document."""
+        """Return the adjacency of the document.
+
+        :return: the adjacency from this document proto
+        """
         return self._pb_body.adjacency
 
     @adjacency.setter
-    def adjacency(self, adjacency_value: int):
-        """Set the adjacency of the document."""
-        self._pb_body.adjacency = adjacency_value
+    def adjacency(self, value: int):
+        """Set the adjacency of the document.
+
+        :param value: the value of the adjacency to be set
+        """
+        self._pb_body.adjacency = value
 
     @property
     def score(self):
-        """Return the score of the document."""
+        """Return the score of the document.
+
+        :return: the score attached to this document as `:class:NamedScore`
+        """
         return NamedScore(self._pb_body.score)
 
     @score.setter
     def score(self, value: Union[jina_pb2.NamedScoreProto, NamedScore]):
-        """Set the score of the document."""
+        """Set the score of the document.
+
+        :param value: the value to set the score of the Document from
+        """
         if isinstance(value, jina_pb2.NamedScoreProto):
             self._pb_body.score.CopyFrom(value)
         elif isinstance(value, NamedScore):
@@ -758,16 +870,22 @@ class Document(ProtoTypeMixin, Traversable):
     def convert_blob_to_uri(
         self, width: int, height: int, resize_method: str = 'BILINEAR', **kwargs
     ):
-        """Assuming :attr:`blob` is a _valid_ image, set :attr:`uri` accordingly"""
+        """Assuming :attr:`blob` is a _valid_ image, set :attr:`uri` accordingly
+        :param width: the width of the blob
+        :param height: the height of the blob
+        :param resize_method: the resize method name
+        :param kwargs: reserved for maximum compatibility when using with ConvertDriver
+        """
         png_bytes = png_to_buffer(self.blob, width, height, resize_method)
         self.uri = 'data:image/png;base64,' + base64.b64encode(png_bytes).decode()
 
     def convert_uri_to_blob(
-        self, color_axis: int = -1, uri_prefix: str = None, **kwargs
+        self, color_axis: int = -1, uri_prefix: Optional[str] = None, **kwargs
     ):
         """Convert uri to blob
 
         :param color_axis: the axis id of the color channel, ``-1`` indicates the color channel info at the last axis
+        :param uri_prefix: the prefix of the uri
         :param kwargs: reserved for maximum compatibility when using with ConvertDriver
         """
         self.blob = to_image_blob(
@@ -825,8 +943,8 @@ class Document(ProtoTypeMixin, Traversable):
 
         :param charset: charset may be any character set registered with IANA
         :param base64: used to encode arbitrary octet sequences into a form that satisfies the rules of 7bit.
-         Designed to be efficient for non-text 8 bit and binary data. Sometimes used for text data that
-         frequently uses non-US-ASCII characters.
+            Designed to be efficient for non-text 8 bit and binary data. Sometimes used for text data that
+            frequently uses non-US-ASCII characters.
         :param kwargs: reserved for maximum compatibility when using with ConvertDriver
         """
 
@@ -844,8 +962,8 @@ class Document(ProtoTypeMixin, Traversable):
 
         :param charset: charset may be any character set registered with IANA
         :param base64: used to encode arbitrary octet sequences into a form that satisfies the rules of 7bit.
-        Designed to be efficient for non-text 8 bit and binary data.
-        Sometimes used for text data that frequently uses non-US-ASCII characters.
+            Designed to be efficient for non-text 8 bit and binary data.
+            Sometimes used for text data that frequently uses non-US-ASCII characters.
         :param kwargs: reserved for maximum compatibility when using with ConvertDriver
         """
 
@@ -872,11 +990,17 @@ class Document(ProtoTypeMixin, Traversable):
             raise NotImplementedError
 
     def MergeFrom(self, doc: 'Document'):
-        """Merge the content of target :param:doc into current document."""
+        """Merge the content of target :param:doc into current document.
+
+        :param doc: the document to merge from
+        """
         self._pb_body.MergeFrom(doc.proto)
 
     def CopyFrom(self, doc: 'Document'):
-        """Copy the content of target :param:doc into current document."""
+        """Copy the content of target :param:doc into current document.
+
+        :param doc: the document to copy from
+        """
         self._pb_body.CopyFrom(doc.proto)
 
     def __mermaid_str__(self):
@@ -913,11 +1037,12 @@ class Document(ProtoTypeMixin, Traversable):
 
         return '\n'.join(results)
 
-    def _mermaid_to_url(self, img_type) -> str:
+    def _mermaid_to_url(self, img_type: str) -> str:
         """
         Rendering the current flow as a url points to a SVG, it needs internet connection
-        :param kwargs: keyword arguments of :py:meth:`to_mermaid`
-        :return: the url points to a SVG
+
+        :param img_type: the type of image to be generated
+        :return: the url pointing to a SVG
         """
         if img_type == 'jpg':
             img_type = 'img'
@@ -941,7 +1066,7 @@ classDiagram
         """Displays the object in IPython as a side effect"""
         self.plot(inline_display=True)
 
-    def plot(self, output: str = None, inline_display: bool = False) -> None:
+    def plot(self, output: Optional[str] = None, inline_display: bool = False) -> None:
         """
         Visualize the Document recursively.
 
@@ -974,5 +1099,8 @@ classDiagram
 
     @property
     def non_empty_fields(self) -> Tuple[str]:
-        """Return the set fields of the curren"""
+        """Return the set fields of the current document that are not empty
+
+        :return: the tuple of non-empty fields
+        """
         return tuple(field[0].name for field in self.ListFields())
